==> fr.ac6.linux.utils_1.0.0.202110251403.jar: resources/scripts/make_utils.sh <==
#
# Utility variables and functions for make invokation
#

: ${dest_dir:="DESTDIR"}

require_script_once "multilib_utils.sh"

declare -g -a make_options=() # This script is sourced in a function; without -g the variable would be local

if [ "$current_buildstep" = "install" ]; then
	# "make install" quite often fails when executed in parallel and anyway do not benefit a lot from parallelism
	sequential_build=true 
fi

if $sequential_build; then
	make_options+=("-j1")
elif [ $PARALLEL_MAKE -gt 1 ]; then
	make_options+=("-j$PARALLEL_MAKE")
else
	make_options+=("-j1")
fi

if [ X"$KEEP_GOING" != X"false" ]; then
	make_options+=("-k")
fi

has_makefile_in() {
	local dir="$1"
	if [ -z "$dir" ]; then dir="$buildDir"; fi
	dir=$(readlink -m $dir)
	local makefile
	for makefile in GNUmakefile Makefile makefile; do
		if [ -r "$dir/$makefile" ]; then
			return 0
		fi
	done
	return 1
}

check_makefile() {
	local buildDir="."
	if [[ " $* " =~ " -C " ]]; then
		local buildDir="$(echo " $* " | sed -e 's/^.*-C[[:space:]]*\([^[:space:]]*\).*$/\1/')"
	fi
	if ! has_makefile_in $buildDir; then
		log "Nothing to do for compiling $recipe_name"
		return 1
	fi
	return 0
}

do_make() {
	if ! check_makefile "$@"; then return 0; fi
	mapfile -t make_build_options < <(split_in_words "$make_other_flags")
	log_exec "CFLAGS='$CFLAGS'" "CXXFLAGS='$CXXFLAGS'" make "${make_options[@]}" "${make_build_options[@]}" "$@"
}

do_make_noerror() {
	if ! check_makefile "$@"; then return 0; fi
	mapfile -t make_build_options < <(split_in_words "$make_other_flags")
	log_run "CFLAGS='$CFLAGS'" "CXXFLAGS='$CXXFLAGS'" make "${make_options[@]}" "${make_build_options[@]}" "$@"
}

do_make_clean() {
	poison_recipe_task compile
	unconditional_task

	do_make clean $make_clean_args "$@"
}

do_make_all() {
	local target=${default_make_target:-all}
	do_make ${target/no-default-make-target/} "$@"
}

do_make_all_noerror() {
	local target=${default_make_target:-all}
	do_make_noerror ${target/no-default-make-target/} "$@"
}

do_make_install() {
	if ! has_makefile_in $buildDir; then
		error 1 "No rule for installing $recipe_name"
	fi
	local target=${default_install_target:-install}
	mapfile -t make_install_options < <(split_in_words "$make_install_other_flags")
	do_make ${target} $dest_dir=$installDir "${make_install_options[@]}" "$@"
}

do_make_install_noerror() {
	if ! has_makefile_in $buildDir; then
		error 1 "No rule for installing $recipe_name"
	fi
	local target=${default_install_target:-install}
	mapfile -t make_install_options < <(split_in_words "$make_install_other_flags")
	do_make_noerror ${target} $dest_dir=$installDir "${make_install_options[@]}" "$@"
}

# Buildstep defaults
makefile_do_compile() {
	do_make_all "$@"
}

makefile_do_install() {
	do_make_install "$@"
}
	
# Yocto-compatibility layer
oe_runmake_call() {
	do_make_noerror "$@"
}

oe_runmake() {
	do_make "$@"
}

==> fr.ac6.linux.utils_1.0.0.202202211611.jar: resources/scripts/make_utils.sh <==
#
# Utility variables and functions for make invokation
#

: ${dest_dir:="DESTDIR"}
: ${PARALLEL_MAKE:=$CORE_COUNT}
: ${sequential_build:=false}

if [ "$PARALLEL_MAKE" = "MAX" ]; then
	PARALLEL_MAKE=$CORE_COUNT
fi

require_script_once "multilib_utils.sh"

declare -g -a make_options=() # This script is sourced in a function; without -g the variable would be local

if [ "$current_buildstep" = "install" ]; then
	# "make install" quite often fails when executed in parallel and anyway do not benefit a lot from parallelism
	sequential_build=true 
fi

if $sequential_build; then
	make_options+=("-j1")
	PARRALEL_MAKE=0
elif [ $PARALLEL_MAKE -gt 1 ]; then
	make_options+=("-j$PARALLEL_MAKE")
else
	make_options+=("-j1")
fi

if [ X"$KEEP_GOING" != X"false" ]; then
	make_options+=("-k")
fi

has_makefile_in() {
	local dir="$1"
	if [ -z "$dir" ]; then dir="$buildDir"; fi
	dir=$(readlink -m $dir)
	local makefile
	for makefile in GNUmakefile Makefile makefile; do
		if [ -r "$dir/$makefile" ]; then
			return 0
		fi
	done
	return 1
}

check_makefile() {
	local buildDir="."
	if [[ " $* " =~ " -C " ]]; then
		local buildDir="$(echo " $* " | sed -e 's/^.*-C[[:space:]]*\([^[:space:]]*\).*$/\1/')"
	fi
	if ! has_makefile_in $buildDir; then
		log "No makefile in '$buildDir' for $recipe_name"
		return 1
	fi
	return 0
}

do_make() {
	if ! check_makefile "$@"; then return 1; fi
	mapfile -t make_build_options < <(split_in_words "$make_other_flags")
	log_exec "CFLAGS='$CFLAGS'" "CXXFLAGS='$CXXFLAGS'" make "${make_options[@]}" "${make_build_options[@]}" "$@"
}

do_make_noerror() {
	if ! check_makefile "$@"; then return 0; fi
	mapfile -t make_build_options < <(split_in_words "$make_other_flags")
	log_run "CFLAGS='$CFLAGS'" "CXXFLAGS='$CXXFLAGS'" make "${make_options[@]}" "${make_build_options[@]}" "$@"
}

do_make_clean() {
	poison_recipe_task compile
	unconditional_task

	do_make_noerror clean $make_clean_args "$@"
}

do_make_all() {
	local target=${default_make_target:-all}
	do_make ${target/no-default-make-target/} "$@"
}

do_make_all_noerror() {
	local target=${default_make_target:-all}
	do_make_noerror ${target/no-default-make-target/} "$@"
}

do_make_install() {
	if ! check_makefile "$@"; then return 1; fi
	local target=${default_install_target:-install}
	mapfile -t make_install_options < <(split_in_words "$make_install_other_flags")
	do_make ${target} $dest_dir=$installDir "${make_install_options[@]}" "$@"
}

do_make_install_noerror() {
	if ! check_makefile "$@"; then return 0; fi
	local target=${default_install_target:-install}
	mapfile -t make_install_options < <(split_in_words "$make_install_other_flags")
	do_make_noerror ${target} $dest_dir=$installDir "${make_install_options[@]}" "$@"
}

# Buildstep defaults
makefile_do_compile() {
	do_make_all "$@"
}

makefile_do_install() {
	do_make_install "$@"
}

makefile_do_clean() {
	do_make_clean "$@"
}
	
# Yocto-compatibility layer
oe_runmake_call() {
	do_make_noerror "$@"
}

oe_runmake() {
	do_make "$@"
}
